<?xml version="1.0" encoding="ISO-8859-1"?> <!-- -*- html -*- -->
<!DOCTYPE xsl:stylesheet
  PUBLIC "-//NetBSD/DTD NetBSD XSLT 1.0 DTD//EN"
	 "http://www.NetBSD.org/XML/htdocs/share/xml/xslt10-netbsd.dtd">

<!-- $NetBSD: portpage.xsl,v 1.16 2006/04/16 18:45:13 heinz Exp $ -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:html="http://www.w3.org/1999/xhtml"
		exclude-result-prefixes="html"
		version="1.0">

<!-- XSL magic to create a Port/<port>/ - index page -->

<xsl:template match="portpage">
  <xsl:variable name="port" select="ancestor::webpage/@portpage"/>
  <xsl:call-template name="porthead">
    <xsl:with-param name="port" select="$port"/>
    <xsl:with-param name="logo" select="./@logo"/>
    <xsl:with-param name="logoh" select="./@logoheight"/>
    <xsl:with-param name="logow" select="./@logowidth"/>
  </xsl:call-template>
  <table width="100%" border="0" cellspacing="0" cellpadding="2">
    <tr>
      <td>
        <xsl:apply-templates select="*[name() != 'portinfo']"/>
      </td>
      <td valign="top" width="200">
        <xsl:apply-templates select="portinfo"/>
      </td>
    </tr>
  </table>
</xsl:template>

<xsl:template name="porthead">
  <table border="0" width="98%" summary="Port Header and Logo">
    <tr>
      <td align="left" valign="middle"
          style="vertical-align: middle;">
        <h1>NetBSD/<xsl:value-of select="$port"/></h1>
      </td>
      <td align="right" valign="middle"
          style="vertical-align: middle;">
        <xsl:if test="@logo">
	<img>
	  <xsl:attribute name="src">
	    <xsl:text>/images/ports/</xsl:text>
	    <xsl:value-of select="$port"/>
	    <xsl:text>/</xsl:text>
	    <xsl:value-of select="$logo"/>
	  </xsl:attribute>
	  <xsl:attribute name="height">
	    <xsl:value-of select="$logoh"/>
	  </xsl:attribute>
	  <xsl:attribute name="width">
	    <xsl:value-of select="$logow"/>
	  </xsl:attribute>
          <xsl:attribute name="alt">
            <xsl:value-of select="$port"/>
	    <xsl:text>-logo</xsl:text>
          </xsl:attribute>
	</img> 
        </xsl:if>
      </td>
    </tr>
  </table>
</xsl:template>

<xsl:template match="portabout">
  <xsl:variable name="port" select="ancestor::webpage/@portpage"/>
  <h2><xsl:text>About NetBSD/</xsl:text><xsl:value-of select="$port"/></h2>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="portsection">
  <xsl:variable name="title" select="./@title"/>
  <h2><xsl:value-of select="$title"/></h2>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="portnews">
  <xsl:variable name="port" select="ancestor::webpage/@portpage"/>
  <h2><xsl:text>NetBSD/</xsl:text><xsl:value-of select="$port"
  /><xsl:text> News</xsl:text></h2>
  <xsl:for-each select="child::portnewsitem">
    <dl>
      <dt>
        <b>
          <xsl:value-of select="./@date"/>
          <xsl:text>:</xsl:text>
        </b>
        &nbsp;
        <xsl:value-of select="./@title"/>
      </dt>
      <dd>
        <xsl:apply-templates/>
      </dd>
    </dl>
  </xsl:for-each>
  <xsl:if test="child::portnewsarchive">
    <p><a href="news.html">
	<xsl:text>Archive of NetBSD/</xsl:text>
	<xsl:value-of select="$port"/>
	<xsl:text> news items</xsl:text>
    </a></p>
  </xsl:if>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="portinfo">
  <xsl:variable name="port" select="ancestor::webpage/@portpage"/>

  <div class="portinfo">
    <xsl:if test="child::portinfoitem">
      <h2><xsl:text>NetBSD/</xsl:text><xsl:value-of select="$port"
      /><xsl:text> Information</xsl:text></h2>

      <ul>
        <xsl:for-each select="child::portinfoitem">
          <li><xsl:apply-templates/></li>
        </xsl:for-each>
      </ul>
    </xsl:if>

    <xsl:if test="child::portml">
      <h2>Mailing Lists</h2>

      <ul>
        <xsl:for-each select="child::portml">
          <xsl:variable name="ml" select="./@name"/>
          <li><font face="helvetica, arial" size="-1">
            <xsl:text>The </xsl:text>
            <a>
              <xsl:attribute name="href">
                <xsl:text>../../MailingLists/#port-</xsl:text>
                <xsl:value-of select="$ml"/>
              </xsl:attribute>
              <xsl:text>NetBSD/</xsl:text>
              <xsl:value-of select="$ml"/>
              <xsl:text> mailing list</xsl:text>
            </a>
            <xsl:text>, covering </xsl:text>
            <xsl:value-of select="./text()"/>
            <xsl:text>:</xsl:text>
            <br/>
            <xsl:text>[</xsl:text>
            &nbsp;
            <a>
              <xsl:attribute name="href">
                <xsl:text>http://www.NetBSD.org/cgi-bin/subscribe_list.pl?list=port-</xsl:text>
                <xsl:value-of select="$ml"/>
              </xsl:attribute>
              <xsl:text>subscribe</xsl:text>
            </a>
            &nbsp;
            <xsl:text>|</xsl:text>
            &nbsp;
            <a>
              <xsl:attribute name="href">
                <xsl:text>http://mail-index.NetBSD.org/port-</xsl:text>
                <xsl:value-of select="$ml"/>
              </xsl:attribute>
              <xsl:text>archive</xsl:text>
            </a>
            &nbsp;
            <xsl:text>]</xsl:text>
            <br/>
            &nbsp;
          </font></li>
        </xsl:for-each>
      </ul>
    </xsl:if>

    <xsl:if test="child::portcurrentitem">
      <h2>Current Releases</h2>

      <ul>
        <xsl:for-each select="child::portcurrentitem">
          <li><font face="helvetica, arial" size="-1">
          <xsl:if test="@type='ftp'">
            <a>
              <xsl:attribute name="href">
                <xsl:text>ftp://ftp.NetBSD.org/pub/NetBSD/NetBSD-&release.latest;/</xsl:text>
                <xsl:value-of select="$port"/>
                <xsl:text>/</xsl:text>
              </xsl:attribute>
              <xsl:text>NetBSD/</xsl:text>
              <xsl:value-of select="$port"/>
              <xsl:text> &release.latest; via FTP</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='installnotes'">
            <a>
              <xsl:attribute name="href">
                <xsl:text>ftp://ftp.NetBSD.org/pub/NetBSD/NetBSD-&release.latest;/</xsl:text>
                <xsl:value-of select="$port"/>
                <xsl:text>/INSTALL.html</xsl:text>
              </xsl:attribute>
              <xsl:text>NetBSD/</xsl:text>
              <xsl:value-of select="$port"/>
              <xsl:text> &release.latest; Install Notes</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='ra'">
            <a>
              <xsl:attribute name="href">
                <xsl:text>../../Releases/formal-&release.latest.major;/NetBSD-&release.latest;.html</xsl:text>
              </xsl:attribute>
              <xsl:text>NetBSD &release.latest; release announcement</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='port-changes'">
            <a>
              <xsl:attribute name="href">
		<xsl:text>../../Changes/changes-&release.latest;.html#port-</xsl:text>
		<xsl:value-of select="$port" />
              </xsl:attribute>
	      <xsl:text>NetBSD/</xsl:text>
	      <xsl:value-of select="$port" />
	      <xsl:text> changes to &release.latest;</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='netbsd-changes'">
            <a>
              <xsl:attribute name="href">
		<xsl:text>ftp://ftp.NetBSD.org/pub/NetBSD/NetBSD-&release.latest;/CHANGES</xsl:text>
              </xsl:attribute>
	      <xsl:text>Changes from NetBSD &release.previous.major;.0
to NetBSD &release.latest.major;.0</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='packages'">
            <xsl:text>NetBSD/</xsl:text>
            <xsl:value-of select="$port"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="@packages-for"/>
            <a>
              <xsl:attribute name="href">
                <xsl:text>ftp://ftp.NetBSD.org/pub/NetBSD/packages/</xsl:text>
                <xsl:value-of select="@packages-for"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select="$port"/>
                <xsl:text>/</xsl:text>
              </xsl:attribute>
              <xsl:text> pre-built binary packages</xsl:text>
            </a>
            <xsl:text> via the NetBSD </xsl:text>
            <a>
              <xsl:attribute name="href">
                <xsl:text>../../Documentation/software/packages.html</xsl:text>
              </xsl:attribute>
              <xsl:text>Packages Collection</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='mirrors'">
            <a href="../../mirrors/">
              <xsl:text>NetBSD FTP Mirror Sites</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="@type='cdroms'">
            <a href="../../Sites/cdroms.html">
              <xsl:text>NetBSD on CD-ROM</xsl:text>
            </a>
          </xsl:if>
          <xsl:if test="not(@type)">
            <xsl:apply-templates/>
          </xsl:if>
          </font></li>
        </xsl:for-each>
      </ul>
    </xsl:if>

    <xsl:if test="child::portfutureitem">
      <h2>Future Releases</h2>

      <ul>
        <xsl:for-each select="child::portfutureitem">
          <xsl:variable name="type" select="./@type"/>
          <li><font face="helvetica, arial" size="-1">
            <xsl:if test="@type='changes'">
            <a>
              <xsl:attribute name="href">
                <xsl:text>../../Changes/changes-&release.next.major;.html#port-</xsl:text>
                <xsl:value-of select="$port"/>
              </xsl:attribute>
              <xsl:text>NetBSD/</xsl:text>
              <xsl:value-of select="$port"/>
              <xsl:text> changes from &release.latest.major; to &release.next.major;</xsl:text>
            </a>
            </xsl:if>
            <xsl:if test="@type='snapshots'">
            <a>
              <xsl:attribute name="href">
                <xsl:text>ftp://ftp.NetBSD.org/pub/NetBSD/arch/</xsl:text>
                <xsl:value-of select="$port"/>
                <xsl:text>/snapshot/</xsl:text>
              </xsl:attribute>
              <xsl:text>binary snapshots</xsl:text>
            </a>
            <xsl:text> of </xsl:text>
            <a href="../../Releases/release-map.html">
              <xsl:text>NetBSD-current</xsl:text>
            </a>
            </xsl:if>
          </font></li>
        </xsl:for-each>
      </ul>
    </xsl:if>

    <h2>Related Links</h2>

    <ul>
      <xsl:for-each select="child::portlinkitem">
        <li><font face="helvetica, arial" size="-1"><xsl:apply-templates/></font></li>
      </xsl:for-each>
      <li><font face="helvetica, arial" size="-1">
        <a>
          <xsl:attribute name="href">
            <xsl:text>mailto:port-</xsl:text>
            <xsl:value-of select="$port"/>
            <xsl:text>-maintainer@NetBSD.org</xsl:text>
          </xsl:attribute>
          <xsl:text>Mail the NetBSD/</xsl:text>
          <xsl:value-of select="$port"/>
          <xsl:text> port maintainer</xsl:text>
        </a>
        </font>
      </li>
    </ul>
  </div>
</xsl:template>

<!-- handled by iteration; ignore but match -->
<xsl:template match="portlinkitem|portnewsitem|portinfoitem|portfutureitem|portnewsarchive|portml">
</xsl:template>

</xsl:stylesheet>

