<?xml version="1.0" encoding="ISO-8859-1"?> <!-- -*- html -*- -->
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">
                          <!ENTITY reg "&#174;">]>

<!-- $NetBSD: webpage.xsl,v 1.29 2006/03/21 11:21:56 mishka Exp $ -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:html="http://www.w3.org/1999/xhtml"
		exclude-result-prefixes="html"
		version="1.0">

<xsl:include href="portpage.xsl"/>

<xsl:param name="toc.section.depth" select="3" />

<xsl:template match="processing-instruction('sdataEntity')">
  <xsl:text disable-output-escaping="yes">&amp;</xsl:text>
  <xsl:value-of select="substring-before(.,' [')" />
  <xsl:text>;</xsl:text>
</xsl:template>

<!-- local overrides, from website-common.xsl -->
<!-- ==================================================================== -->

<xsl:template name="allpages.banner"/>

<!-- ==================================================================== -->

<xsl:template name="webpage.table.footer"/>

<xsl:template name="webpage.footer">
  <xsl:variable name="page" select="."/>
  <xsl:variable name="cvstag" select="$page/config[@param='cvstag']/@value"/>
  <xsl:variable name="footers" select="$page/config[@param='footer']
                                       |$page/config[@param='footlink']
                                       |$autolayout/autolayout/config[@param='footer']
                                       |$autolayout/autolayout/config[@param='footlink']"/>

  <xsl:variable name="tocentry" select="$autolayout//*[@id=$page/@id]"/>
  <xsl:variable name="toc" select="($tocentry/ancestor-or-self::toc[1]
                                   | $autolayout//toc[1])[last()]"/>

  <xsl:variable name="feedback">
    <xsl:choose>
      <xsl:when test="$page/config[@param='feedback.href']">
        <xsl:value-of select="($page/config[@param='feedback.href'])[1]/@value"/>
      </xsl:when>
      <xsl:when test="$autolayout/autolayout/config[@param='feedback.href']">
        <xsl:value-of select="($autolayout/autolayout/config[@param='feedback.href'])[1]/@value"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$feedback.href"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:choose>
    <xsl:when test="not($toc)">
      <xsl:message>
        <xsl:text>Cannot determine TOC for </xsl:text>
        <xsl:value-of select="$page/@id"/>
      </xsl:message>
    </xsl:when>
    <xsl:when test="$toc/@id = $page/@id">
      <!-- nop; this is the home page -->
    </xsl:when>
    <xsl:otherwise>
      <div class="navfoot">
        <xsl:if test="$footer.hr != 0"><hr/></xsl:if>
        <table border="0" summary="Footer navigation">
          <tr>
            <td class="foothome">
              <span class="foothome">
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="homeuri"/>
                  </xsl:attribute>
                  <img src="/images/NetBSD-flag.png"
                    alt="[NetBSD flag]" border="0" width="90" height="90"/>
                </a>
              </span>
            </td>
            <td class="foothome">
              <span class="foothome">
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="homeuri"/>
                  </xsl:attribute>
                  <xsl:value-of select="$foothome.text"/>
                </a>
              </span>
              <br/>
            </td>
          </tr>
        </table>
        <xsl:if test="$footer.hr != 0"><hr/></xsl:if>
      </div>
    </xsl:otherwise>
  </xsl:choose>

  <p/>

  <xsl:apply-templates select="$footers" mode="footer.link.mode"/>

  <xsl:choose>
    <xsl:when test="$feedback != ''">
      <span class="footfeed">
        <a>
          <xsl:choose>
            <xsl:when test="$feedback.with.ids != 0">
              <xsl:attribute name="href">
                <xsl:value-of select="$feedback"/>
                <xsl:value-of select="$page/@id"/>
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="href">
                <xsl:value-of select="$feedback"/>
              </xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="$feedback.link.text"/>
        </a>
      </span>
    </xsl:when>
  </xsl:choose>

  &#160;
  <span class="foottag">
    <xsl:text>Generated from </xsl:text>
    <em>
    <xsl:call-template name="string.subst">
      <xsl:with-param name="string" select="$cvstag"/>
      <xsl:with-param name="target" select="'$'"/>
      <xsl:with-param name="replacement" select="'%'"/>
    </xsl:call-template>
    </em>
  </span>
  <br/>

  <span class="footcopy">
    <a>
      <xsl:attribute name="href">/Misc/disclaimer.html</xsl:attribute>
      <xsl:choose>
        <xsl:when test="head/copyright">
          <xsl:apply-templates select="head/copyright" mode="footer.mode"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates mode="footer.mode"
                             select="$autolayout/autolayout/copyright"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:text>ALL RIGHTS RESERVED.</xsl:text>
      <br/>
      <xsl:text>NetBSD</xsl:text>
	<sup><xsl:text>&reg;</xsl:text></sup>
	<xsl:text> is a registered trademark of The NetBSD
	Foundation, Inc.</xsl:text>
    </a>
  </span>

  <xsl:if test="$sequential.links != 0">
    <xsl:variable name="prev">
      <xsl:call-template name="prev.page"/>
    </xsl:variable>
    <xsl:variable name="next">
      <xsl:call-template name="next.page"/>
    </xsl:variable>
    <xsl:variable name="ptoc"
                  select="$autolayout/autolayout//*[$prev=@id]"/>
    <xsl:variable name="ntoc"
                  select="$autolayout/autolayout//*[$next=@id]"/>

    <xsl:choose>
      <xsl:when test="$prev != ''">
        <xsl:call-template name="link.to.page">
          <xsl:with-param name="frompage" select="$tocentry"/>
          <xsl:with-param name="page" select="$ptoc"/>
          <xsl:with-param name="linktext" select="'Prev'"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>&#160;</xsl:otherwise>
    </xsl:choose>
    &#160;
    <xsl:choose>
      <xsl:when test="$next != ''">
        <xsl:call-template name="link.to.page">
          <xsl:with-param name="frompage" select="$tocentry"/>
          <xsl:with-param name="page" select="$ntoc"/>
          <xsl:with-param name="linktext" select="'Next'"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>&#160;</xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:template>

<xsl:template match="sect1[@role = 'NotInToc']"  mode="toc" />
<xsl:template match="sect2[@role = 'NotInToc']"  mode="toc" />
<xsl:template match="sect3[@role = 'NotInToc']"  mode="toc" />
<xsl:template match="sect4[@role = 'NotInToc']"  mode="toc" />

<xsl:template match="webpage">
  <xsl:variable name="page" select="."/>
  <xsl:variable name="port" select="$page/@portpage"/>
  <xsl:variable name="id">
    <xsl:call-template name="object.id"/>
  </xsl:variable>

  <xsl:variable name="filename">
    <xsl:apply-templates select="." mode="filename"/>
  </xsl:variable>

  <xsl:variable name="tocentry" select="$autolayout/autolayout//*[$id=@id]"/>
  <xsl:variable name="toc" select="$tocentry/ancestor-or-self::toc"/>

  <html>
    <xsl:apply-templates select="head" mode="head.mode"/>
    <xsl:apply-templates select="config" mode="head.mode"/>
    <body class="website">
      <xsl:call-template name="body.attributes"/>

      <div class="{name(.)}">
        <a name="{$id}"/>

        <xsl:if test="$banner.before.navigation != 0">
          <xsl:call-template name="allpages.banner"/>
        </xsl:if>

<!-- we don't want the default toc at the top -->
<!--
        <xsl:if test="$toc">
          <div class="navhead">
            <xsl:apply-templates select="$toc">
              <xsl:with-param name="pageid" select="@id"/>
            </xsl:apply-templates>
            <xsl:if test="$header.hr != 0"><hr/></xsl:if>
          </div>
        </xsl:if>
-->
        <xsl:if test="$banner.before.navigation = 0">
          <xsl:call-template name="allpages.banner"/>
        </xsl:if>

	<xsl:choose>
	  <xsl:when test="not($port)">
            <xsl:apply-templates select="head/title" mode="title.mode"/>
	  </xsl:when>
	</xsl:choose>

        <xsl:apply-templates select="child::*[name(.)!='webpage']"/>

        <xsl:call-template name="process.footnotes"/>

        <xsl:call-template name="webpage.footer"/>
      </div>
    </body>
  </html>
</xsl:template>

<xsl:template match="parentsec">
  <xsl:variable name="parentsec" select="."/>
  <hr/>
  <xsl:value-of select="$locale.backto" />
  <xsl:text>&nbsp;</xsl:text>
  <em><a href="{$parentsec/@url}"><xsl:value-of select="$parentsec/@text"/></a></em>
</xsl:template>

<xsl:template match="citerefentry">
  <!-- <xsl:variable name="webpage" select="ancestor::webpage"/> -->
  <xsl:variable name="release" select="ancestor::webpage/@release"/> 
  <a>
      <xsl:attribute name="href">
	<xsl:text>http://netbsd.gw.com/cgi-bin/man-cgi?</xsl:text>
	<xsl:value-of select="refentrytitle"/>
  	<xsl:text>+</xsl:text>
  	<xsl:value-of select="manvolnum"/>
  	<xsl:text>+NetBSD-</xsl:text>
	<xsl:choose>
	  <xsl:when test="not($release)">
  	    <xsl:text>current</xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
	    <xsl:value-of select="$release"/>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:attribute>	
  <xsl:value-of select="refentrytitle"/>
  <xsl:text>(</xsl:text>
  <xsl:value-of select="manvolnum"/>
  <xsl:text>)</xsl:text>
  </a>
</xsl:template>

<!--
  With mode="plaintext" the template produces plain text without any markup.
  This can be used to get nicer output than the simple text concatenation of
  "xsl:value-of".
-->
<xsl:template match="citerefentry" mode="plaintext">
  <xsl:value-of select="refentrytitle"/>
  <xsl:text>(</xsl:text>
  <xsl:value-of select="manvolnum"/>
  <xsl:text>)</xsl:text>
</xsl:template>

<xsl:template match="small">
  <font size="-1">
  <xsl:apply-templates />
  </font>
</xsl:template>

<xsl:template match="currentsrc">
   <xsl:variable name="currentsrc" select="."/>
   <a>
     <xsl:attribute name="href">
       <xsl:text>http://cvsweb.NetBSD.org/bsdweb.cgi/</xsl:text>
       <xsl:value-of select="$currentsrc"/> 
       <xsl:text>?rev=HEAD&amp;content-type=text/x-cvsweb-markup</xsl:text>
     </xsl:attribute>
     <xsl:value-of select="$currentsrc"/>
   </a>
</xsl:template>


<!-- Generate a change list -->
<xsl:template match="sect1[@role='toc']">
  <xsl:variable name="title" select="title"/>
  <xsl:if test="$title != ''">
    <h2 class="title"><xsl:apply-templates select="title" mode="plaintext"/>
    </h2>
  </xsl:if>
  <xsl:for-each select="sect2">
    <h3 class="title">
      <a name="{@id}"><xsl:apply-templates select="title" mode="plaintext"/></a>
    </h3>
    <ul>
      <xsl:for-each select="sect3">
        <li><a href="#{@id}"><xsl:apply-templates select="title" mode="plaintext"/>
	</a></li>
      </xsl:for-each>
    </ul>
  </xsl:for-each>
  <xsl:for-each select="sect2">
    <hr/>
    <h3 class="title"><xsl:apply-templates select="title" mode="plaintext"/>
    </h3>
    <xsl:for-each select="sect3">
      <xsl:apply-templates/>
    </xsl:for-each>
  </xsl:for-each>
</xsl:template>

<xsl:template match="sect1[@role='toc']/sect2/sect3/title">
  <h4 class="title">
    <a name="{ancestor::sect3/@id}"/>
    <xsl:apply-templates/> (<a href="#{ancestor::sect2/@id}"><xsl:value-of select="$top.link.text"/></a>)
  </h4>
</xsl:template>

<!--
  With mode="plaintext" the template produces plain text without any markup.
  This can be used to get nicer output than the simple text concatenation of
  "xsl:value-of".
-->
<xsl:template match="sect1[@role='toc']/sect2/sect3/title" mode="plaintext">
    <xsl:apply-templates mode="plaintext" /> 
</xsl:template>

<!--
  XXX: this change possible should go into DocBook/Website repository,
  or it might be xsltproc "bug".

  Do not provide expicit namespace for html:* nodes. Otherwise it would
  result in stray 'xmlns=""' attributes with <html:form> and friends, which
  is also affects on descendant nodes, like XMLized <input>, etc.
-->
<xsl:template match="html:*">
  <xsl:element name="{local-name(.)}">
    <xsl:apply-templates select="@*" mode="copy"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

</xsl:stylesheet>
